package cn.pluss.platform.level.impl;

import java.util.List;
import java.util.Map;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.transaction.annotation.Transactional;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import cn.pluss.platform.entity.Level;
import cn.pluss.platform.level.LevelService;
import cn.pluss.platform.mapper.LevelMapper;

@Transactional
@RequiredArgsConstructor
@Slf4j
@Service("levelService")
public class LevelServiceImpl extends ServiceImpl<LevelMapper, Level> implements LevelService {

    @Override
    public Level queryLevel(Level level) {
        return baseMapper.queryLevel(level);
    }

    @Override
    public List<Level> queryLevelList(Level level) {
        return baseMapper.queryLevelList(level);
    }

    @Override
    public void saveLevel(Level level) {
        baseMapper.saveLevel(level);
    }

    @Override
    public void updateLevel(Level level) {
        baseMapper.updateLevel(level);
    }

    @Override
    public void deleteLevel(Level level) {
        baseMapper.deleteLevel(level);
    }

    @Override
    public List<Level> queryLevelPage(Map map) {
        return baseMapper.queryLevelPage(map);
    }

    @Override
    public Integer queryLevelPageCount(Map map) {
        return baseMapper.queryLevelPageCount(map);
    }
}

